#
# spec file for package python-docformatter
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-docformatter
Version:        1.4
Release:        1.11
Summary:        Utility to re-format docstrings per PEP 257
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/myint/docformatter
Source:         https://files.pythonhosted.org/packages/source/d/docformatter/docformatter-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires:       python-untokenize
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
%if %{suse_version} <= 1500
BuildRequires:  python2-mock
%endif
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module untokenize}
# /SECTION
%python_subpackages

%description
Docformatter currently automatically formats docstrings to follow a
subset of the PEP 257 conventions. Below are the relevant items quoted
from PEP 257.

- For consistency, always use triple double quotes around docstrings.
- Triple quotes are used even though the string fits on one line.
- Multi-line docstrings consist of a summary line just like a one-line
  docstring, followed by a blank line, followed by a more elaborate
  description.
- The BDFL recommends inserting a blank line between the last paragraph
  in a multi-line docstring and its closing quotes, placing the closing
  quotes on a line by themselves.

docformatter also handles some of the PEP 8 conventions.

- Don't write string literals that rely on significant trailing
  whitespace. Such trailing whitespace is visually indistinguishable
  and some editors (or more recently, reindent.py) will trim them.

%prep
%setup -q -n docformatter-%{version}
sed -i -e '/^#!\//, 1d' docformatter.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/docformatter
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative docformatter

%postun
%python_uninstall_alternative docformatter

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.rst
%python_alternative %{_bindir}/docformatter
%{python_sitelib}/*

%changelog
* Thu May 20 2021 pgajdos@suse.com
- version update to 1.4
  * Add --docstring-length flag
  * Not add period for summary formatted as title
  * Added command line exclude option
- use %%pytest macro
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.3.1
  * A pydoc reference such as ':see:' should not be start of sentence
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 1.3
  * no upstream changelog
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1:
  * fixes for python 3.7
  * varioius cleanups
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Use noun phrase in summary.
* Thu May 24 2018 toddrme2178@gmail.com
- Update to version 1.0
  * Document and test disabling of wrapping
  * Add @kapsh
  * Make text wrapping trigger more conservative
  * Adds support for argument lists
- Spec file cleanups
* Tue Nov  7 2017 toddrme2178@gmail.com
- initial version
